@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-    Copyright (C) 2007-2020 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2024 Ahmet Öztürk (aoz_2@yahoo.com)
 
     This file is part of Lifeograph.
 
@@ -28,6 +28,7 @@
 
 #include <gtkmm.h>
 
+#include "lifeograph.hpp"
 #include "helpers.hpp"
 #include "settings.hpp"
 #include "ui_login.hpp"
@@ -49,18 +50,32 @@ class AppWindow : public Gtk::ApplicationWindow
                                     ~AppWindow();
         static AppWindow*           p;
 
-        void                        update_title();
+        void                        refresh_title();
+        void                        set_title( const Ustring& title )
+        { m_L_title->set_text( title ); }
+        void                        set_subtitle( const Ustring& subt )
+        {
+            if( subt.empty() )
+                m_L_subtitle->hide();
+            else
+            {
+                m_L_subtitle->show();
+                m_L_subtitle->set_text( subt );  // TODO: 3.1: use markup
+            }
+        }
 
         void                        enter_selection_mode()
-        { m_Hb_main->get_style_context()->add_class( "selection-mode" ); }
+        { m_Hb_main->add_css_class( "selection-mode" ); }
         void                        exit_selection_mode()
-        { m_Hb_main->get_style_context()->remove_class( "selection-mode" ); }
+        { m_Hb_main->remove_css_class( "selection-mode" ); }
 
-        bool                        confirm_dismiss_element( const Ustring&,
+        void                        confirm_dismiss_element( const Ustring&,
+                                                             const FuncVoid&,
                                                              Gtk::Widget* = nullptr );
 
         void                        login();
-        bool                        finish_login_session( bool = true );
+        void                        check_finish_diary_session( bool = true );
+        void                        finish_login_session();
         void                        logout( bool );
 
         void                        handle_login();
@@ -72,33 +87,44 @@ class AppWindow : public Gtk::ApplicationWindow
 
         static void                 show_about();
 
-        void                        show_info( Gtk::MessageType, const Ustring&,
+        void                        show_info( const Ustring&,
                                                const Ustring& = "",
                                                InfoResponse = RESP_OK );
-        void                        handle_infobar_response( int );
-        void                        hide_infobar();
+        void                        handle_infobar_response();
 
         bool                        write_backup();
 
+        void                        focus_next_panel();
         void                        refresh_panels();
         void                        fix_paned_positions_if_needed();
 
+        void                        init_textview_theme_classes();
+        void                        add_textview_theme_class( Theme* );
+        void                        remove_textview_theme_class( Theme* );
+        void                        update_textview_theme_class( Theme* );
+        void                        clear_textview_theme_classes();
+
         // METHODS INVOLVING MULTIPLE PANELS AT ONCE
+        void                        show_elem( DiaryElement* );
+        void                        show_elem( DEID );
         void                        show_entry( Entry* );
 
+        void                        go_to_prev();
+        void                        go_to_next();
+
         // AUTO LOGOUT FUNCTIONALITY
         bool                        handle_idle();
-        void                        freeze_auto_logout();
-        void                        unfreeze_auto_logout();
+        void                        freeze_auto_close();
+        void                        unfreeze_auto_close();
         void                        update_auto_logout_count_down();
-        void                        disable_auto_logout_for_the_session();
-        void                        reenable_auto_logout_for_the_session();
-        bool                        is_auto_logout_in_use()
-        { return( m_auto_logout_freeze_level == 0 ); }
+        // void                        disable_auto_logout_for_the_session();
+        // void                        reenable_auto_logout_for_the_session();
+        bool                        is_auto_close_in_use()
+        { return( m_auto_close_freeze_level == 0 ); }
         void                        handle_auto_logout_toggled();
-        void                        update_toggle_auto_logout_gui( bool = false );
+        void                        update_toggle_auto_close_gui( bool = false );
 
-        bool                        on_event( GdkEvent* ) override;
+        bool                        on_event( const Glib::RefPtr< const Gdk::Event >& );
 
         // UI FUNCTIONALITY
         UILogin*                    UI_login{ nullptr };
@@ -106,34 +132,37 @@ class AppWindow : public Gtk::ApplicationWindow
         UIEntry*                    UI_entry{ nullptr };
         UIExtra*                    UI_extra{ nullptr };
 
+        static int                  parallel_thread_count;
+
     protected:
-        bool                        on_delete_event( GdkEventAny* ) override;
+        bool                        on_close_request() override;
 
         // WIDGETS
         Gtk::Box*                   m_Bx_main;
         Gtk::HeaderBar*             m_Hb_main;
+        Gtk::Label*                 m_L_title;
+        Gtk::Label*                 m_L_subtitle;
         Gtk::Stack*                 m_St_main{ nullptr };
-        Gtk::InfoBar*               m_IB_info;
+        Gtk::Revealer*              m_Rv_info;
         Gtk::Label*                 m_L_info;
         Gtk::Button*                m_B_info;
 
         Gtk::Paned*                 m_Pd_main{ nullptr };
         Gtk::Paned*                 m_Pd_extra{ nullptr };
 
-        Gtk::Button*                m_B_back;
-
         sigc::connection            m_connection_backup;
 
         int                         m_seconds_remaining{ LOGOUT_COUNTDOWN + 1 };
         sigc::connection            m_connection_timeout;
-        int                         m_auto_logout_freeze_level{ 1 }; // reflects the result of all factors
-        InfoResponse                m_resp_cur; // FIXME: a most unfortunate solution!!
-        bool                        m_flag_info_is_visible{ false };
+        int                         m_auto_close_freeze_level{ 1 }; // reflects the result of all factors
+        bool                        m_F_block_backup_on_idle{ false };
+        InfoResponse                m_info_resp_cur;
+
+        std::map< const String, Glib::RefPtr< Gtk::CssProvider > > m_textview_css_providers;
 
         // ACTIONS
-        Action                      m_A_toggle_auto_logout;
-        Action                      m_A_logout_wo_saving;
-        Action                      m_A_show_preferences;
+        R2Action                    m_A_disable_auto_close;
+        R2Action                    m_A_close_diary_wo_save;
 };
 
 } // end of namespace LIFEO
