@@ -240,7 +240,7 @@ namespace VT
                          TCT_CMPNT_INDENT       = 0x100,
                          TCT_CMPNT_NUMBER       = 0x200;
     // source fields:
-    static constexpr int TCT_SRC_TITLE          = 0x0,
+    static constexpr int TCT_SRC_TITLE          = 0x0, // means text for paragraphs
                          TCT_SRC_ANCESTRAL      = 0x1,
                          TCT_SRC_DESCRIPTION    = 0x2,
                          TCT_SRC_URI            = 0x3;
@@ -586,38 +586,6 @@ class NamedElement
         Ustring                 m_name;
 };
 
-// COMPARISON FUNCTIONS
-template< typename T >
-struct FuncCmpDiaryElemByDate
-{
-    bool operator()( T* l, T* r ) const
-    { return( l->get_date() > r->get_date() ); }
-};
-
-template< typename T >
-struct FuncCmpDiaryElemById
-{
-    bool operator()( T* l, T* r ) const
-    { return( l->get_id() < r->get_id() ); }
-};
-
-struct FuncCmpNamedElemByName
-{
-    bool operator()( NamedElement* l, NamedElement* r ) const
-    { return( l->get_name() < r->get_name() ); }
-};
-
-// TYPEDEFS
-using MapUstringUstring         = std::map< Ustring, Ustring, FuncCmpStrings >;
-using ListDiaryElems            = std::list< DiaryElement* >;
-using SetDiaryElemsByName       = std::set< DiaryElement*, FuncCmpNamedElemByName >;
-using VecDiaryElems             = std::vector< DiaryElement* >;
-using ListEntries               = std::list< Entry* >;
-using VecEntries                = std::vector< Entry* >;
-using VecEntriesIter            = std::vector< Entry* >::iterator;
-using VecConstEntries           = std::vector< const Entry* >;
-using PoolDEIDs                 = std::map< DEID, DiaryElement* >;
-
 // DIARYELEMENT ====================================================================================
 class DiaryElement : public NamedElement
 {
@@ -686,37 +654,6 @@ class DiaryElement : public NamedElement
         DEID                    m_id      { DEID_UNSET };
 };
 
-using SignalVoidDeid        = sigc::signal< void( DEID ) >;
-using SignalVoidElem        = sigc::signal< void( LIFEO::DiaryElement* ) >;
-using SignalVoidElemstatus  = sigc::signal< void( LIFEO::ElemStatus ) >;
-using FuncVoidElem          = std::function< void( DiaryElement* ) >;
-
-template< class T >
-Ustring
-create_unique_name_for_map( const std::map< Ustring, T, FuncCmpStrings >& map,
-                            const Ustring& name0 )
-{
-    Ustring name = name0;
-    for( int i = 1; map.find( name ) != map.end(); i++ )
-    {
-        name = Glib::ustring::compose( "%1 %2", name0, i );
-    }
-
-    return name;
-}
-template< class T >
-Ustring
-create_unique_name_for_map( const std::multimap< Ustring, T >& map, const Ustring& name0 )
-{
-    Ustring name = name0;
-    for( int i = 1; map.find( name ) != map.end(); i++ )
-    {
-        name = Glib::ustring::compose( "%1 %2", name0, i );
-    }
-
-    return name;
-}
-
 // DIARYELEMENT DATA SOURCE (Entries and Paragraphs) ===============================================
 class DiaryElemDataSrc : public DiaryElement
 {
@@ -724,8 +661,8 @@ class DiaryElemDataSrc : public DiaryElement
         DiaryElemDataSrc( Diary* const d , const Ustring& s, DateV date,
                           ElemStatus es = ES::EXPANDED )
         : DiaryElement( d, s, es ), m_date( date ), m_date_finish( date ) {}
-        DiaryElemDataSrc( Diary* const d )
-        : DiaryElement( d, "" ) {}
+        DiaryElemDataSrc( Diary* const d, ElemStatus es = ES::EXPANDED )
+        : DiaryElement( d, "", es ) {}
 
         DateV                   get_date() const        { return m_date; }
         DateV                   get_date_finish() const
@@ -782,6 +719,68 @@ class DiaryElemDataSrc : public DiaryElement
         DateV                   m_date_finish   { Date::NOT_SET }; // is always set for entries
 };
 
+// COMPARISON FUNCTIONS
+struct FuncCmpDiaryElemByDate
+{
+    bool operator()( DiaryElemDataSrc* l, DiaryElemDataSrc* r ) const
+    { return( l->get_date() > r->get_date() ); }
+};
+
+struct FuncCmpDiaryElemById
+{
+    bool operator()( DiaryElement* l, DiaryElement* r ) const
+    { return( l->get_id() < r->get_id() ); }
+};
+
+struct FuncCmpNamedElemByName
+{
+    bool operator()( NamedElement* l, NamedElement* r ) const
+    { return( l->get_name() < r->get_name() ); }
+};
+
+// TYPEDEFS
+using MapUstringUstring         = std::map< Ustring, Ustring, FuncCmpStrings >;
+using ListDiaryElems            = std::list< DiaryElement* >;
+using SetDiaryElemsByName       = std::multiset< DiaryElement*, FuncCmpNamedElemByName >;
+using SetDiaryElemSrcByID       = std::set< DiaryElemDataSrc*, FuncCmpDiaryElemById >;
+using VecDiaryElems             = std::vector< DiaryElement* >;
+using ListEntries               = std::list< Entry* >;
+using VecEntries                = std::vector< Entry* >;
+using VecEntriesIter            = std::vector< Entry* >::iterator;
+using VecConstEntries           = std::vector< const Entry* >;
+using PoolDEIDs                 = std::map< DEID, DiaryElement* >;
+
+using SignalVoidDeid            = sigc::signal< void( DEID ) >;
+using SignalVoidElem            = sigc::signal< void( LIFEO::DiaryElement* ) >;
+using SignalVoidElemstatus      = sigc::signal< void( LIFEO::ElemStatus ) >;
+using FuncVoidElem              = std::function< void( DiaryElement* ) >;
+
+template< class T >
+Ustring
+create_unique_name_for_map( const std::map< Ustring, T, FuncCmpStrings >& map,
+                            const Ustring& name0 )
+{
+    Ustring name = name0;
+    for( int i = 1; map.find( name ) != map.end(); i++ )
+    {
+        name = Glib::ustring::compose( "%1 %2", name0, i );
+    }
+
+    return name;
+}
+template< class T >
+Ustring
+create_unique_name_for_map( const std::multimap< Ustring, T >& map, const Ustring& name0 )
+{
+    Ustring name = name0;
+    for( int i = 1; map.find( name ) != map.end(); i++ )
+    {
+        name = Glib::ustring::compose( "%1 %2", name0, i );
+    }
+
+    return name;
+}
+
 // STRING DEFINITION ELEMENT =======================================================================
 class StringDefElem : public DiaryElement
 {
