@@ -349,6 +349,24 @@ Entry::add_sibling_after( Entry* e )
     e->update_sibling_orders();
 }
 
+void
+Entry::add_sibling_chain_after( Entry* ec )
+{
+    // parents
+    for( Entry* e = ec; e; e = e->m_p2next )
+        e->m_p2parent = m_p2parent;
+
+    Entry* e_sibl_last { ec->get_sibling_last() };
+    if( m_p2next )
+        m_p2next->m_p2prev = e_sibl_last;
+    e_sibl_last->m_p2next = m_p2next;
+
+    ec->m_p2prev = this;
+    m_p2next = ec;
+
+    ec->update_sibling_orders();
+}
+
 void
 Entry::append_entry_as_paras( Entry* entry_r )
 {
@@ -969,7 +987,7 @@ Entry::insert_text( UstringSize pos, const Ustring& new_text, const ListHiddenFo
                 insert_text_to_para();
 
             // please note that when pos==end, split_at just creates an empty new paragraph
-            para = add_paragraph_after( para->split_at( pos_split + para_text.length() ),
+            para = add_paragraph_after( para->split_at( pos_split + para_text.length(), parser ),
                                         para,
                                         F_inherit_style && !para_inherit );
             pos_split = 0;
@@ -990,6 +1008,8 @@ Entry::insert_text( UstringSize pos, const Ustring& new_text, const ListHiddenFo
 
     if( !para_text.empty() )
         insert_text_to_para();
+    else
+        parser->parse( para );
 
     // UNDO
     if( F_add_undo )
@@ -1402,11 +1422,10 @@ Entry::add_paragraph_after( Paragraph* para, Paragraph* para_before, bool F_inhe
         else if( m_p2para_last == para_last )
             m_p2para_last = para_last->m_p2next;
 
-        // TODO: remove, no reason to update the name when p[1] is updated
-        // if( para->m_order_in_host == 1 )
-        //     update_name();
-        // else
-        if( para->m_order_in_host == 0 )
+        // update the name when the entry was empty at the time the second para is added:
+        if( para->m_order_in_host == 1 && m_p2para_1st->is_empty() )
+            update_name();
+        else if( para->m_order_in_host == 0 )
             set_paragraph_1st( para );
     }
 
@@ -1793,8 +1812,7 @@ Entry::add_tag( Entry* tag, Value value )
     if( is_empty() )
         add_paragraph_before( "", nullptr );
 
-    add_paragraph_before( tag->get_name(), nullptr )->
-            add_format( VT::HFT_TAG, "", 0, tag->get_name().length() );
+    add_paragraph_before( tag->get_name(), nullptr )->add_format_tag( tag, 0 );
 
     if( value != 1.0 )
         m_p2para_last->append( STR::compose( value ),
