@@ -115,6 +115,7 @@ class Entry : public DiaryElemDataSrc
         void                    add_child_last( Entry* );
         void                    add_sibling_before( Entry* );
         void                    add_sibling_after( Entry* );
+        void                    add_sibling_chain_after( Entry* );
         void                    append_entry_as_paras( Entry* );
         static int64_t          compare_names( Entry* e1, Entry* e2 )
         { return( e1->m_name.compare( e2->m_name ) ); }
@@ -380,8 +381,14 @@ class Entry : public DiaryElemDataSrc
         ListEntries             get_sub_tags( const Entry* ) const;
         void                    add_tag( Entry*, Value = 1.0 );
 
-        const SetDiaryElemsByName&
-        get_references() const { return m_referring_elems; }
+        SetDiaryElemsByName
+        get_references() const
+        {
+            SetDiaryElemsByName set;
+            for( auto& e : m_referring_elems )
+                set.insert( e );
+            return set;
+        }
 
         int
         get_reference_count() const { return int( m_referring_elems.size() ); }
@@ -391,9 +398,9 @@ class Entry : public DiaryElemDataSrc
         clear_references() { m_referring_elems.clear(); }
 
         void
-        add_referring_elem( DiaryElement* elem ) { m_referring_elems.insert( elem ); }
+        add_referring_elem( DiaryElemDataSrc* elem ) { m_referring_elems.insert( elem ); }
         void
-        remove_referring_elem( DiaryElement* elem )
+        remove_referring_elem( DiaryElemDataSrc* elem )
         {
             // checking existence is crucial for the cases when there are multiple instances of
             // the same tag and removal has already been carried out before
@@ -513,7 +520,7 @@ class Entry : public DiaryElemDataSrc
         Entry*                  m_p2next        { nullptr };
 
         // ON-THE-FLY VALUES
-        SetDiaryElemsByName     m_referring_elems;
+        SetDiaryElemSrcByID     m_referring_elems;
         // double                  m_scroll_pos    { 0.0 };
         int                     m_cursor_pos    { 0 };
 
@@ -543,12 +550,12 @@ typedef PoolEntries::const_reverse_iterator EntryIterConstRev;
 typedef std::multimap< Ustring, Entry*, FuncCmpStrings > PoolEntryNames;
 
 // A SUBSET OF ENTRIES =============================================================================
-class SetEntries : public std::set< Entry*, FuncCmpDiaryElemById< Entry > >
+class SetEntries : public std::set< Entry*, FuncCmpDiaryElemById >
 {
     public:
         SetEntries() {}
         SetEntries( std::initializer_list< Entry* > list )
-        : std::set< Entry*, FuncCmpDiaryElemById< Entry > >( list ) {}
+        : std::set< Entry*, FuncCmpDiaryElemById >( list ) {}
 
         using GValue = Glib::Value< LIFEO::SetEntries* >;
 
