@@ -23,6 +23,7 @@
 #include "filter.hpp"
 #include "diary.hpp"
 #include "../app_window.hpp"
+#include "../widgets/widget_filter.hpp"
 #include "src/diaryelements/diarydata.hpp"
 
 
@@ -229,17 +230,16 @@ FiltererIs::get_as_string( Ustring& string ) const
 Ustring
 FiltererIs::get_as_human_readable_str() const
 {
-    auto elem { m_p2diary->get_element( m_id ) };
+    auto elem { m_p2container->m_p2diary->get_element( m_id ) };
     return( STR::compose( is_not() ? _( "Is NOT" ) : _( "Is" ), " ", m_id,
                           " (", elem ? elem->get_name() : _( "not found" ), ")" ) );
 }
 
 // FILTERER DESCENDANT OF ==========================================================================
-FiltererDescendantOf::FiltererDescendantOf( Diary* d, FiltererContainer* ctr, DEID id,
-                                            bool F_or_itself )
-: Filterer( d, ctr ), m_F_or_itself( F_or_itself )
+FiltererDescendantOf::FiltererDescendantOf( FiltererContainer* ctr, DEID id, bool F_or_itself )
+: Filterer( ctr ), m_F_or_itself( F_or_itself )
 {
-    m_entry_p = d->get_entry_by_id( id );
+    m_entry_p = ctr->m_p2diary->get_entry_by_id( id );
 }
 
 bool
@@ -770,8 +770,8 @@ FiltererIsCurrentEntry::get_as_human_readable_str() const
 }
 
 // FILTERER CHILD FILTER ===========================================================================
-FiltererChildFilter::FiltererChildFilter( Diary* d, FiltererContainer* ctr, Filter* filter )
-: Filterer( d, ctr ), m_p2filter( filter )
+FiltererChildFilter::FiltererChildFilter( FiltererContainer* ctr, Filter* filter )
+: Filterer( ctr ), m_p2filter( filter )
 {
     if( m_p2filter ) m_FC_stack = m_p2filter->get_filterer_stack();
 }
@@ -958,17 +958,6 @@ FiltererContainer::remove_filterer( Filterer* filterer )
             break;
         }
     }
-
-    update_state();
-}
-
-void
-FiltererContainer::toggle_not( Filterer* filterer )
-{
-    if( Lifeograph::is_internal_operations_ongoing() ) return;
-
-    filterer->toggle_not();
-    update_state();
 }
 
 // this is re-implemented in WidgetFilter:
@@ -1040,9 +1029,9 @@ FiltererContainer::set_from_string( const Ustring& string )
                 ++index;
                 const DEID id_c  { STR::get_i32( line, ++index ) };
                 const auto type  { STR::get_i32( line, ++index ) };
-                container->add_filterer_subtagged_by( m_p2diary->get_entry_by_id( id_p ),
-                                                      m_p2diary->get_entry_by_id( id_c ),
-                                                      rel, type );
+                container->add< FiltererSubtaggedBy >( m_p2diary->get_entry_by_id( id_p ),
+                                                       m_p2diary->get_entry_by_id( id_c ),
+                                                       rel, type );
                 break;
             }
             case 'c':   // completion
@@ -1051,7 +1040,7 @@ FiltererContainer::set_from_string( const Ustring& string )
                 const double double_b{ STR::get_d( line, i_double ) };
                 i_double++;
                 const double double_e{ STR::get_d( line, i_double ) };
-                container->add_filterer_completion( double_b, double_e );
+                container->add< FiltererCompletion >( double_b, double_e );
                 break;
             }
             case 'd':   // between dates
@@ -1061,7 +1050,7 @@ FiltererContainer::set_from_string( const Ustring& string )
                 const int   i_f_icl_e = i_date;
                 i_date++;
                 const DateV date_e{ STR::get_i64( line, i_date ) };
-                container->add_filterer_between_dates(
+                container->add< FiltererBetweenDates >(
                         date_b, line[ 2 ] == '[', date_e, line[ i_f_icl_e ] == '[' );
                 break;
             }
@@ -1072,25 +1061,25 @@ FiltererContainer::set_from_string( const Ustring& string )
                 const int  i_f_icl_e = i_id;
                 i_id++;
                 const DEID id_e{ STR::get_i32( line, i_id ) };
-                container->add_filterer_between_entries(
+                container->add< FiltererBetweenEntries >(
                         m_p2diary->get_entry_by_id( id_b ), line[ 2 ] == '[',
                         m_p2diary->get_entry_by_id( id_e ), line[ i_f_icl_e ] == '[' );
                 break;
             }
             case 'f':   // favorite
-                container->add_filterer_favorite();
+                container->add< FiltererFavorite >();
                 if( line[ 2 ] == 'n' ) // support for old diaries
                     set_last_filterer_not();
                 break;
             case 'g':   // is image
-                container->add_filterer_is_image();
+                container->add< FiltererIsImage >();
                 break;
             case 'h':   // theme (DEID)
             {
                 if( version < 1 )
                 {
                     const Ustring&& name{ line.substr( 3 ) };
-                    container->add_filterer_theme( m_p2diary->get_theme( name ) );
+                    container->add< FiltererTheme >( m_p2diary->get_theme( name ) );
                     if( line[ 2 ] == 'F' ) // support for old diaries
                         set_last_filterer_not();
                 }
@@ -1098,44 +1087,44 @@ FiltererContainer::set_from_string( const Ustring& string )
                 {
                     const DEID id    { STR::get_i32( line.substr( 3 ) ) };
                     const auto theme { m_p2diary->get_element2< Theme >( id ) };
-                    container->add_filterer_theme( theme );
+                    container->add< FiltererTheme >( theme );
                 }
                 break;
             }
             case 'i':   // is entry (DEID)
             {
                 const DEID id{ STR::get_i32( line.substr( 3 ) ) };
-                container->add_filterer_is( id );
+                container->add< FiltererIs >( id );
                 if( line[ 2 ] == 'F' ) // support for old diaries
                     set_last_filterer_not();
                 break;
             }
             case 'k':   // is current entry
             {
-                container->add_filterer_current_entry( line[ 2 ] == 'D' );
+                container->add< FiltererIsCurrentEntry >( line[ 2 ] == 'D' );
                 break;
             }
             case 'l':   // child filter (DEID)
             {
-                container->add_filterer_child_filter(
+                container->add< FiltererChildFilter >(
                         m_p2diary->get_filter( std::stoul( line.substr( 2 ) ) ) );
                 break;
             }
             case 'n':   // descendant of (DEID)
             {
                 const DEID id{ STR::get_i32( line.substr( 9 ) ) };
-                container->add_filterer_descendant_of( id, line[ 3 ] == 'I' );
+                container->add< FiltererDescendantOf >( id, line[ 3 ] == 'I' );
                 if( line[ 2 ] == 'F' ) // support for old diaries
                     set_last_filterer_not();
                 break;
             }
             case 'o':   // has map coordinates (bool)
-                container->add_filterer_has_coords();
+                container->add< FiltererHasCoords >();
                 break;
             case 'r':   // tagged/referenced by (DEID)
             {
                 const DEID id{ STR::get_i32( line.substr( 3 ) ) };
-                container->add_filterer_tagged_by( m_p2diary->get_entry_by_id( id ) );
+                container->add< FiltererTaggedBy >( m_p2diary->get_entry_by_id( id ) );
                 if( line[ 2 ] == 'F' ) // support for old diaries
                     set_last_filterer_not();
                 break;
@@ -1151,16 +1140,16 @@ FiltererContainer::set_from_string( const Ustring& string )
                     if( line[ 5 ] == 'D' ) status |= ES::SHOW_DONE;
                     if( line[ 6 ] == 'C' ) status |= ES::SHOW_CANCELED;
                 }
-                container->add_filterer_status( status );
+                container->add< FiltererStatus >( status );
                 break;
             }
             case 't':   // trashed
-                container->add_filterer_trashed();
+                container->add< FiltererTrashed >();
                 if( line[ 2 ] == 'n' ) // support for old diaries
                     set_last_filterer_not();
                 break;
             case 'u':   // unit
-                container->add_filterer_unit( line.substr( 3 ) );
+                container->add< FiltererUnit >( line.substr( 3 ) );
                 if( line[ 2 ] == 'F' ) // support for old diaries
                     set_last_filterer_not();
                 break;
@@ -1184,18 +1173,18 @@ FiltererContainer::set_from_string( const Ustring& string )
                     case 'B': type = VT::REMAINING; break;
                 }
 
-                container->add_filterer_tag_value( m_p2diary->get_entry_by_id( id_tag ), type,
-                                                   range_b, f_incl_b, range_e, f_incl_e );
+                container->add< FiltererTagValue >( m_p2diary->get_entry_by_id( id_tag ), type,
+                                                    range_b, f_incl_b, range_e, f_incl_e );
                 break;
             }
             // case 'w':   // dropped, was used by Owner
             //     break;
             case 'x':   // contains text (Ustring)
-                container->add_filterer_contains_text( line.substr( 4 ),
-                                                       line[ 2 ] == 'C', line[ 3 ] == 'N' );
+                container->add< FiltererContainsText >( line.substr( 4 ),
+                                                        line[ 2 ] == 'C', line[ 3 ] == 'N' );
                 break;
             case 'y':   // title style
-                container->add_filterer_title_style( line[ 2 ] );
+                container->add< FiltererTitleStyle >( line[ 2 ] );
                 break;
             case 'z':   // size
             {
@@ -1206,7 +1195,7 @@ FiltererContainer::set_from_string( const Ustring& string )
                 const bool   f_incl_e { line[ index ] == '[' };
                 const double range_e  { line[ ++index ] == '_' ? -1 : STR::get_d( line, index ) };
 
-                container->add_filterer_size( type_ch, range_b, f_incl_b, range_e, f_incl_e );
+                container->add< FiltererSize >( type_ch, range_b, f_incl_b, range_e, f_incl_e );
                 break;
             }
             case '=':   // equals
@@ -1215,17 +1204,17 @@ FiltererContainer::set_from_string( const Ustring& string )
             {
                 int i_double{ 2 };
                 const double value{ STR::get_d( line, i_double ) };
-                container->add_filterer_equals( line[ 1 ], value );
+                container->add< FiltererEquals >( line[ 1 ], value );
                 break;
             }
             case '#':   // haeding level
-                container->add_filterer_heading_level( std::stoi( line.substr( 2 ) ) );
+                container->add< FiltererHeadingLevel >( std::stoi( line.substr( 2 ) ) );
                 break;
             case '(':   // sub group
-                container = container->add_filterer_subgroup();
+                container = container->add< FiltererContainer >();
                 break;
             case ')':   // end of sub group
-                container = container->m_p2container;
+                container = this;
                 break;
             case '|':
                 m_F_or = true;
@@ -1241,8 +1230,6 @@ FiltererContainer::set_from_string( const Ustring& string )
                 break;
         }
     }
-
-    update_logic_label();
 }
 
 const Ustring Filter::DEFINITION_DEFAULT    { "F&\nFt~\nF!\nFsNOPdc" };
@@ -1262,11 +1249,7 @@ Filter::get_filterer_stack() const
     if( m_definition.empty() )
         return nullptr;
 
-    FiltererContainer* fc{ new FiltererContainer( m_p2diary, nullptr ) };
-
-    fc->set_from_string( m_definition );
-
-    return fc;
+    return( new FiltererContainer( m_p2diary, m_definition ) );
 }
 
 bool
@@ -1308,3 +1291,70 @@ Filter::get_as_skvvec() const
     return sv;
 }
 
+// UI FUNCTIONS ====================================================================================
+void FiltererStatus::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererStatusUI, FiltererStatus >( this ); }
+
+void FiltererSize::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererSizeUI, FiltererSize >( this ); }
+
+void FiltererFavorite::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererFavoriteUI, FiltererFavorite >( this ); }
+
+void FiltererTrashed::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererTrashedUI, FiltererTrashed >( this ); }
+
+void FiltererUnit::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererUnitUI, FiltererUnit >( this ); }
+
+void FiltererIs::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererIsUI, FiltererIs >( this ); }
+
+void FiltererDescendantOf::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererDescendantOfUI, FiltererDescendantOf >( this ); }
+
+void FiltererTaggedBy::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererTaggedByUI, FiltererTaggedBy >( this ); }
+
+void FiltererSubtaggedBy::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererSubtaggedByUI,FiltererSubtaggedBy >( this ); }
+
+void FiltererTagValue::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererTagValueUI, FiltererTagValue >( this ); }
+
+void FiltererTheme::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererThemeUI, FiltererTheme >( this ); }
+
+void FiltererBetweenDates::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererBetweenDatesUI, FiltererBetweenDates >( this ); }
+
+void FiltererBetweenEntries::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererBetweenEntriesUI, FiltererBetweenEntries >( this ); }
+
+void FiltererCompletion::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererCompletionUI, FiltererCompletion >( this ); }
+
+void FiltererContainsText::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererContainsTextUI, FiltererContainsText >( this ); }
+
+void FiltererChildFilter::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererChildFilterUI, FiltererChildFilter >( this ); }
+
+void FiltererIsImage::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererIsImageUI, FiltererIsImage >( this ); }
+
+void FiltererHasCoords::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererHasCoordsUI, FiltererHasCoords >( this ); }
+
+void FiltererTitleStyle::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererTitleStyleUI, FiltererTitleStyle >( this ); }
+
+void FiltererHeadingLevel::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererHeadingLevelUI, FiltererHeadingLevel >( this ); }
+
+void FiltererEquals::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererEqualsUI, FiltererEquals >( this ); }
+
+void FiltererContainer::initialize_ui( FiltererContainerUI* p2FC )
+{ p2FC->add_filterer< FiltererContainerUI, FiltererContainer >( this ); }
+
