@@ -52,13 +52,14 @@ namespace FOC
 
 // FORWARD DECLARATIONS
 class FiltererContainer;
+class FiltererContainerUI;
 class Filter;
 
 class Filterer
 {
     public:
-        Filterer( Diary* diary, FiltererContainer* p2container )
-        : m_p2container( p2container ), m_p2diary( diary ) {}
+        Filterer( FiltererContainer* p2container )
+        : m_p2container( p2container ) {}
         virtual ~Filterer() {}
 
         virtual bool            is_container() const    { return false; }
@@ -66,6 +67,8 @@ class Filterer
         void                    set_not( bool F_not )   { m_F_not = F_not; }
         void                    toggle_not()            { m_F_not = !m_F_not; }
 
+        virtual void            initialize_ui( FiltererContainerUI* ) = 0;
+
         virtual bool            filter( const Entry* ) const { return true; }
         virtual bool            filter( const Paragraph* ) const { return true; }
         virtual bool            filter( const double ) const { return true; }
@@ -75,10 +78,9 @@ class Filterer
 
         FiltererContainer*      m_p2container;
 
-    protected:
+    // protected:
         bool                    m_F_not     { false };
 
-        Diary*                  m_p2diary   { nullptr };
 };
 
 class FiltererStatus : public Filterer
@@ -89,9 +91,10 @@ class FiltererStatus : public Filterer
 
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererStatus( Diary* d, FiltererContainer* ctr, ElemStatus es = STATUS_DEFAULT )
-        : Filterer( d, ctr ), m_included_statuses( es ) {}
+        FiltererStatus( FiltererContainer* ctr, ElemStatus es = STATUS_DEFAULT )
+        : Filterer( ctr ), m_included_statuses( es ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
@@ -99,7 +102,7 @@ class FiltererStatus : public Filterer
 
         const static int        m_obj_classes { FOC::ENTRIES | FOC::PARAGRAPHS };
 
-    protected:
+    //protected:
         ElemStatus              m_included_statuses;
 };
 
@@ -108,13 +111,14 @@ class FiltererSize : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererSize( Diary* d, FiltererContainer* ctr, char type = VT::SO::CHAR_COUNT::C,
+        FiltererSize( FiltererContainer* ctr, char type = VT::SO::CHAR_COUNT::C,
                       double range_b = -1, bool F_incl_b = false,
                       double range_e = -1, bool F_incl_e = false )
-        : Filterer( d, ctr ), m_type( type ),
+        : Filterer( ctr ), m_type( type ),
           m_range_b( range_b ), m_F_incl_b( F_incl_b ),
           m_range_e( range_e ), m_F_incl_e( F_incl_e ){}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
@@ -122,7 +126,7 @@ class FiltererSize : public Filterer
 
         const static int        m_obj_classes { FOC::ENTRIES | FOC::PARAGRAPHS };
 
-    protected:
+    //protected:
         bool                    filter_v( int ) const;
 
         char                    m_type;
@@ -137,16 +141,17 @@ class FiltererFavorite : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererFavorite( Diary* d, FiltererContainer* ctr )
-        : Filterer( d, ctr ) {}
+        FiltererFavorite( FiltererContainer* ctr )
+        : Filterer( ctr ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::ENTRIES };
 
-    protected:
+    // protected:
 };
 
 class FiltererTrashed : public Filterer
@@ -154,16 +159,17 @@ class FiltererTrashed : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererTrashed( Diary* d, FiltererContainer* ctr )
-        : Filterer( d, ctr ) {}
+        FiltererTrashed( FiltererContainer* ctr )
+        : Filterer( ctr ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::ENTRIES };
 
-    protected:
+    // protected:
 };
 
 class FiltererUnit : public Filterer
@@ -171,16 +177,17 @@ class FiltererUnit : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererUnit( Diary* d, FiltererContainer* ctr, const Ustring& unit )
-        : Filterer( d, ctr ), m_unit( unit ) {}
+        FiltererUnit( FiltererContainer* ctr, const Ustring& unit = "" )
+        : Filterer( ctr ), m_unit( unit ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::ENTRIES };
 
-    protected:
+    // protected:
         Ustring                 m_unit;
 };
 
@@ -189,16 +196,17 @@ class FiltererIs : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererIs( Diary* d, FiltererContainer* ctr, DEID id )
-        : Filterer( d, ctr ), m_id( id ) {}
+        FiltererIs( FiltererContainer* ctr, DEID id = DEID_UNSET )
+        : Filterer( ctr ), m_id( id ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::ENTRIES };
 
-    protected:
+    // protected:
         DEID                    m_id          { DEID_UNSET };
 };
 
@@ -207,15 +215,16 @@ class FiltererDescendantOf : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererDescendantOf( Diary*, FiltererContainer*, DEID, bool );
+        FiltererDescendantOf( FiltererContainer*, DEID = DEID_UNSET, bool = false  );
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::ENTRIES };
 
-    protected:
+    // protected:
         Entry*                  m_entry_p     { nullptr };
         bool                    m_F_or_itself { false };
 };
@@ -225,9 +234,10 @@ class FiltererTaggedBy : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererTaggedBy( Diary* d, FiltererContainer* ctr, Entry* tag )
-        : Filterer( d, ctr ), m_tag( tag ) {}
+        FiltererTaggedBy( FiltererContainer* ctr, Entry* tag = nullptr )
+        : Filterer( ctr ), m_tag( tag ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
@@ -235,7 +245,7 @@ class FiltererTaggedBy : public Filterer
 
         const static int        m_obj_classes { FOC::ENTRIES | FOC::PARAGRAPHS };
 
-    protected:
+    // protected:
         Entry*                  m_tag         { nullptr };
 };
 
@@ -244,12 +254,13 @@ class FiltererSubtaggedBy : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererSubtaggedBy( Diary* d, FiltererContainer* ctr,
-                             Entry* tag_parent, Entry* tag_child,
+        FiltererSubtaggedBy( FiltererContainer* ctr,
+                             Entry* tag_parent = nullptr, Entry* tag_child = nullptr,
                              char rel = '=', int type = VT::LAST )
-        : Filterer( d, ctr ), m_tag_parent( tag_parent ), m_tag_child( tag_child ),
+        : Filterer( ctr ), m_tag_parent( tag_parent ), m_tag_child( tag_child ),
                               m_relation( rel ), m_type( type ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
@@ -257,7 +268,7 @@ class FiltererSubtaggedBy : public Filterer
 
         const static int        m_obj_classes { FOC::ENTRIES | FOC::PARAGRAPHS };
 
-    protected:
+    // protected:
         bool                    filter_common( Entry* ) const;
 
         Entry*                  m_tag_parent  { nullptr };
@@ -271,13 +282,14 @@ class FiltererTagValue : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererTagValue( Diary* d, FiltererContainer* ctr, Entry* tag, int type = VT::REALIZED,
+        FiltererTagValue( FiltererContainer* ctr, Entry* tag = nullptr, int type = VT::REALIZED,
                           double range_b = Constants::INFINITY_MNS, bool F_incl_b = false,
                           double range_e = Constants::INFINITY_PLS, bool F_incl_e = false )
-        : Filterer( d, ctr ), m_tag( tag ), m_type( type ),
+        : Filterer( ctr ), m_tag( tag ), m_type( type ),
           m_range_b( range_b ), m_F_incl_b( F_incl_b ),
           m_range_e( range_e ), m_F_incl_e( F_incl_e ){}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
@@ -285,7 +297,7 @@ class FiltererTagValue : public Filterer
 
         const static int        m_obj_classes { FOC::ENTRIES | FOC::PARAGRAPHS };
 
-    protected:
+    // protected:
         bool                    filter_v( double ) const;
 
         Entry*                  m_tag         { nullptr };
@@ -301,16 +313,17 @@ class FiltererTheme : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererTheme( Diary* d, FiltererContainer* ctr, Theme* theme )
-        : Filterer( d, ctr ), m_theme( theme ) {}
+        FiltererTheme( FiltererContainer* ctr, Theme* theme = nullptr )
+        : Filterer( ctr ), m_theme( theme ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::ENTRIES };
 
-    protected:
+    // protected:
         Theme*                  m_theme       { nullptr };
 };
 
@@ -319,12 +332,13 @@ class FiltererBetweenDates : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererBetweenDates( Diary* d, FiltererContainer* ctr,
+        FiltererBetweenDates( FiltererContainer* ctr,
                               DateV date_b = Date::NOT_SET, bool f_incl_b = false,
                               DateV date_e = Date::NOT_SET, bool f_incl_e = false )
-        : Filterer( d, ctr ), m_date_b( std::min( date_b, date_e ) ), m_F_incl_b( f_incl_b ),
+        : Filterer( ctr ), m_date_b( std::min( date_b, date_e ) ), m_F_incl_b( f_incl_b ),
                               m_date_e( std::max( date_b, date_e ) ), m_F_incl_e( f_incl_e ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
@@ -332,7 +346,7 @@ class FiltererBetweenDates : public Filterer
 
         const static int        m_obj_classes { FOC::ENTRIES | FOC::PARAGRAPHS | FOC::DATES };
 
-    protected:
+    // protected:
         bool                    filter_v( DateV ) const;
 
         DateV                   m_date_b;
@@ -346,19 +360,20 @@ class FiltererBetweenEntries : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererBetweenEntries( Diary* d, FiltererContainer* ctr,
+        FiltererBetweenEntries( FiltererContainer* ctr,
                                 Entry* entry_b = nullptr, bool f_incl_b = false,
                                 Entry* entry_e = nullptr, bool f_incl_e = false )
-        : Filterer( d, ctr ), m_entry_b( entry_b ), m_F_incl_b( f_incl_b ),
+        : Filterer( ctr ), m_entry_b( entry_b ), m_F_incl_b( f_incl_b ),
                               m_entry_e( entry_e ), m_F_incl_e( f_incl_e ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::ENTRIES };
 
-    protected:
+    // protected:
         Entry*                  m_entry_b;
         bool                    m_F_incl_b; // ( or [
         Entry*                  m_entry_e;
@@ -370,18 +385,19 @@ class FiltererCompletion : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererCompletion( Diary* d, FiltererContainer* ctr,
+        FiltererCompletion( FiltererContainer* ctr,
                             double compl_b = 0.0, double compl_e = 100.0 )
-        : Filterer( d, ctr ), m_compl_b( std::min( compl_b, compl_e ) ),
+        : Filterer( ctr ), m_compl_b( std::min( compl_b, compl_e ) ),
                               m_compl_e( std::max( compl_b, compl_e ) ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::ENTRIES };
 
-    protected:
+    // protected:
         double                  m_compl_b;
         double                  m_compl_e;
 };
@@ -391,11 +407,13 @@ class FiltererContainsText : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererContainsText( Diary* d, FiltererContainer* ctr,
-                              const Ustring& text, bool case_sensitive, bool name_only )
-        : Filterer( d, ctr ), m_text( text ), m_case_sensitive( case_sensitive ),
+        FiltererContainsText( FiltererContainer* ctr,
+                              const Ustring& text = "",
+                              bool case_sensitive = false, bool name_only = false )
+        : Filterer( ctr ), m_text( text ), m_case_sensitive( case_sensitive ),
           m_name_only( name_only ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
@@ -403,7 +421,7 @@ class FiltererContainsText : public Filterer
 
         const static int        m_obj_classes { FOC::ENTRIES | FOC::PARAGRAPHS };
 
-    protected:
+    // protected:
         Ustring                 m_text;
         bool                    m_case_sensitive;
         bool                    m_name_only;
@@ -414,9 +432,10 @@ class FiltererIsCurrentEntry : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererIsCurrentEntry( Diary* d, FiltererContainer* ctr, bool F_include_descendants )
-        : Filterer( d, ctr ), m_F_include_descendants( F_include_descendants ) {}
+        FiltererIsCurrentEntry( FiltererContainer* ctr, bool F_include_descendants = false )
+        : Filterer( ctr ), m_F_include_descendants( F_include_descendants ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override { /*has no UI*/ }
         bool                    filter( const Entry* ) const override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
@@ -424,7 +443,7 @@ class FiltererIsCurrentEntry : public Filterer
 
         const static int        m_obj_classes { FOC::ENTRIES | FOC::PARAGRAPHS };
 
-    protected:
+    // protected:
         bool                    m_F_include_descendants;
 };
 
@@ -433,10 +452,11 @@ class FiltererChildFilter : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererChildFilter( Diary*, FiltererContainer*, Filter* );
+        FiltererChildFilter( FiltererContainer*, Filter* = nullptr );
 
         ~FiltererChildFilter();
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
@@ -444,7 +464,7 @@ class FiltererChildFilter : public Filterer
 
         const static int        m_obj_classes { FOC::ENTRIES | FOC::PARAGRAPHS };
 
-    protected:
+    // protected:
         Filter*                 m_p2filter;
         FiltererContainer*      m_FC_stack    { nullptr };
 };
@@ -454,16 +474,17 @@ class FiltererIsImage : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererIsImage( Diary* d, FiltererContainer* ctr )
-        : Filterer( d, ctr ) {}
+        FiltererIsImage( FiltererContainer* ctr )
+        : Filterer( ctr ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::PARAGRAPHS };
 
-    protected:
+    // protected:
 };
 
 class FiltererHasCoords : public Filterer
@@ -471,9 +492,10 @@ class FiltererHasCoords : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererHasCoords( Diary* d, FiltererContainer* ctr )
-        : Filterer( d, ctr ) {}
+        FiltererHasCoords( FiltererContainer* ctr )
+        : Filterer( ctr ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
@@ -481,7 +503,7 @@ class FiltererHasCoords : public Filterer
 
         const static int        m_obj_classes { FOC::ENTRIES | FOC::PARAGRAPHS };
 
-    protected:
+    // protected:
 };
 
 class FiltererTitleStyle : public Filterer
@@ -489,16 +511,17 @@ class FiltererTitleStyle : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererTitleStyle( Diary* d, FiltererContainer* ctr, char style )
-        : Filterer( d, ctr ), m_title_style( style ) {}
+        FiltererTitleStyle( FiltererContainer* ctr, char style = VT::ETS::NAME_ONLY::C )
+        : Filterer( ctr ), m_title_style( style ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Entry* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::ENTRIES };
 
-    protected:
+    // protected:
         char                    m_title_style;
 };
 
@@ -507,16 +530,17 @@ class FiltererHeadingLevel : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererHeadingLevel( Diary* d, FiltererContainer* ctr, int H_levels )
-        : Filterer( d, ctr ), m_H_levels( H_levels ) {}
+        FiltererHeadingLevel( FiltererContainer* ctr, int H_levels = 1<<1 )
+        : Filterer( ctr ), m_H_levels( H_levels ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const Paragraph* ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::PARAGRAPHS };
 
-    protected:
+    // protected:
         int                     m_H_levels;
 };
 
@@ -526,16 +550,17 @@ class FiltererEquals : public Filterer
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
 
-        FiltererEquals( Diary* d, FiltererContainer* ctr, char relation, double value )
-        : Filterer( d, ctr ), m_relation( relation ), m_value( value ) {}
+        FiltererEquals( FiltererContainer* ctr, char relation = '=', double value = 0.0 )
+        : Filterer( ctr ), m_relation( relation ), m_value( value ) {}
 
+        void                    initialize_ui( FiltererContainerUI* ) override;
         bool                    filter( const double ) const override;
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
 
         const static int        m_obj_classes { FOC::NUMBERS };
 
-    protected:
+    // protected:
         char                    m_relation;
         double                  m_value;
 };
@@ -543,7 +568,7 @@ class FiltererEquals : public Filterer
 typedef std::vector< Filterer* > VecFilterers;
 
 // FILTERER CONTAINER ==============================================================================
-class FiltererContainer : public Filterer
+class FiltererContainer final : public Filterer
 {
     public:
         int                     get_obj_classes() const override { return m_obj_classes; }
@@ -559,15 +584,19 @@ class FiltererContainer : public Filterer
             return( obj_classes & FOC::ALL_REAL );
         }
 
-        FiltererContainer( Diary* diary, FiltererContainer* ctr, bool flag_or = false )
-        : Filterer( diary, ctr ), m_F_or( flag_or ) {}
+        FiltererContainer( FiltererContainer* ctr )
+        : Filterer( ctr ), m_p2diary( ctr->m_p2diary ), m_F_or( !ctr->m_F_or ) {}
+
+        FiltererContainer( Diary* p2diary, const Ustring& def )
+        : Filterer( nullptr ), m_p2diary( p2diary )
+        { set_from_string( def ); }
 
         ~FiltererContainer()
         { clear_pipeline(); }
 
-        virtual void            clear_pipeline();
+        void                    clear_pipeline();
 
-        virtual void            update_state() {}
+        void                    initialize_ui( FiltererContainerUI* ) override;
 
         bool                    filter( const Entry* e ) const override
         { return filter_internal( e ); }
@@ -582,89 +611,32 @@ class FiltererContainer : public Filterer
 
         void                    get_as_string( Ustring& ) const override;
         Ustring                 get_as_human_readable_str() const override;
-        virtual void            set_from_string( const Ustring& );
+        void                    set_from_string( const Ustring& );
 
-        virtual void            toggle_logic() {}
-        virtual void            update_logic_label() {}
-
-        virtual void            add_filterer_status( ElemStatus es )
-        { m_pipeline.push_back( new FiltererStatus( m_p2diary, this, es ) ); }
-        virtual void            add_filterer_size( int type,
-                                                   double range_b, bool f_incl_b,
-                                                   double range_e, bool f_incl_e )
-        { m_pipeline.push_back( new FiltererSize( m_p2diary, this, type, range_b, f_incl_b,
-                                                                         range_e, f_incl_e ) ); }
-        virtual void            add_filterer_favorite()
-        { m_pipeline.push_back( new FiltererFavorite( m_p2diary, this ) ); }
-        virtual void            add_filterer_trashed()
-        { m_pipeline.push_back( new FiltererTrashed( m_p2diary, this ) ); }
-        virtual void            add_filterer_unit( const Ustring& unit )
-        { m_pipeline.push_back( new FiltererUnit( m_p2diary, this, unit ) ); }
-        virtual void            add_filterer_is( DEID id )
-        { m_pipeline.push_back( new FiltererIs( m_p2diary, this, id ) ); }
-        virtual void            add_filterer_descendant_of( DEID id, bool F_itself )
-        { m_pipeline.push_back( new FiltererDescendantOf( m_p2diary, this, id, F_itself ) ); }
-        virtual void            add_filterer_tagged_by( Entry* tag )
-        { m_pipeline.push_back( new FiltererTaggedBy( m_p2diary, this, tag ) ); }
-        virtual void            add_filterer_subtagged_by( Entry* tag_p, Entry* tag_c,
-                                                           char rel, int type )
-        { m_pipeline.push_back( new FiltererSubtaggedBy( m_p2diary, this,
-                                                         tag_p, tag_c, rel, type ) ); }
-        virtual void            add_filterer_tag_value( Entry* tag, int type,
-                                                        double range_b, bool f_incl_b,
-                                                        double range_e, bool f_incl_e )
-        { m_pipeline.push_back( new FiltererTagValue( m_p2diary, this, tag, type,
-                                                      range_b, f_incl_b,
-                                                      range_e, f_incl_e ) ); }
-        virtual void            add_filterer_theme( Theme* theme )
-        { m_pipeline.push_back( new FiltererTheme( m_p2diary, this, theme ) ); }
-        virtual void            add_filterer_between_dates( DateV date_b, bool f_incl_b,
-                                                            DateV date_e, bool f_incl_e )
-        { m_pipeline.push_back( new FiltererBetweenDates(
-                m_p2diary, this, date_b, f_incl_b, date_e, f_incl_e ) ); }
-        virtual void            add_filterer_between_entries( Entry* entry_b, bool f_incl_b,
-                                                              Entry* entry_e, bool f_incl_e )
-        { m_pipeline.push_back( new FiltererBetweenEntries(
-                m_p2diary, this, entry_b, f_incl_b, entry_e, f_incl_e ) ); }
-        virtual void            add_filterer_completion( double compl_b, double compl_e )
-        { m_pipeline.push_back( new FiltererCompletion( m_p2diary, this, compl_b, compl_e ) ); }
-        virtual void            add_filterer_contains_text( const Ustring& t, bool cs, bool no )
-        { m_pipeline.push_back( new FiltererContainsText( m_p2diary, this, t, cs, no ) ); }
-        void                    add_filterer_current_entry( bool F_include_descs )
-        { m_pipeline.push_back( new FiltererIsCurrentEntry( m_p2diary, this, F_include_descs ) ); }
-        virtual void            add_filterer_child_filter( Filter* filter )
-        { m_pipeline.push_back( new FiltererChildFilter( m_p2diary, this, filter ) ); }
-        virtual void            add_filterer_is_image()
-        { m_pipeline.push_back( new FiltererIsImage( m_p2diary, this ) ); }
-
-        virtual void            add_filterer_has_coords()
-        { m_pipeline.push_back( new FiltererHasCoords( m_p2diary, this ) ); }
-
-        virtual void            add_filterer_title_style( char title_style )
-        { m_pipeline.push_back( new FiltererTitleStyle( m_p2diary, this, title_style ) ); }
-
-        virtual void            add_filterer_heading_level( int h_levels )
-        { m_pipeline.push_back( new FiltererHeadingLevel( m_p2diary, this, h_levels ) ); }
-
-        virtual void            add_filterer_equals( char relation, double value )
-        { m_pipeline.push_back( new FiltererEquals( m_p2diary, this, relation, value ) ); }
-
-        virtual FiltererContainer*
-                                add_filterer_subgroup()
+        void                    toggle_logic()
         {
-            FiltererContainer* container{ new FiltererContainer( m_p2diary, this, !m_F_or ) };
-            m_pipeline.push_back( container );
-            return container;
+            m_F_or = !m_F_or;
+            // recursion
+            for( auto& filterer : m_pipeline )
+            if( filterer->is_container() )
+                dynamic_cast< FiltererContainer* >( filterer )->toggle_logic();
         }
-        virtual void            remove_filterer( Filterer* );
-        void                    toggle_not( Filterer* );
 
-        virtual void            set_last_filterer_not()
+        template< class T, typename... Args >
+        T*                      add( Args... args )
+        {
+            T* filterer { new T( this, args... ) };
+            m_pipeline.push_back( filterer );
+            return filterer;
+        }
+        void                    remove_filterer( Filterer* );
+
+        void                    set_last_filterer_not()
         { m_pipeline.back()->set_not( true ); }
 
         const static int        m_obj_classes { FOC::EVERYTHING };
 
-    protected:
+    // protected:
         template< typename T >
         bool                    filter_internal( const T item ) const
         {
@@ -677,6 +649,7 @@ class FiltererContainer : public Filterer
                 {
                     if( m_F_or )
                         return true;
+
                 }
                 else
                 if( ! m_F_or )
@@ -686,6 +659,8 @@ class FiltererContainer : public Filterer
             return( ! m_F_or );
         }
 
+        Diary*                  m_p2diary   { nullptr };
+
         VecFilterers            m_pipeline;
 
         bool                    m_F_or;
