@@ -47,7 +47,7 @@ Paragraph::Paragraph( Entry* host, const Ustring& text, ParserBackGround* parser
 }
 
 Paragraph::Paragraph( Paragraph* p, Diary* p2diary )
-:   DiaryElemDataSrc( p2diary ? p2diary : p->m_p2diary ),
+:   DiaryElemDataSrc( p2diary ? p2diary : p->m_p2diary, p->m_status ),
     m_style( p->m_style ), m_host( p->m_host ),
     m_text( p->m_text ), m_uri( p->m_uri ), m_image_size( p->m_image_size )
 {
@@ -120,25 +120,19 @@ Paragraph::get_next_visible() const
 Paragraph*
 Paragraph::get_parent() const
 {
-    Paragraph* prev = m_p2prev;
-
-    while( prev )
+    if( get_heading_level() > VT::PS_SUBHDR ) // nothing can parent a subheading
     {
-        if( prev->is_header() )
-            return nullptr;
+        for( Paragraph* prev = m_p2prev; prev; prev = prev->m_p2prev )
+        {
+            if( prev->is_header() ) // entry title is not a parent
+                break;
 
-        // NOTE: bigger headers have smaller values:
-        if( prev->get_heading_level() < this->get_heading_level() )
-            break;
-
-        if( ( prev->m_style & VT::PS_FLT_INDENT ) < ( this->m_style & VT::PS_FLT_INDENT ) &&
-            !prev->is_empty() ) // an empty line cannot be a parent
-            break;
-
-        prev = prev->m_p2prev;
+            if( prev->is_sub( this ) )
+                return prev;
+        }
     }
 
-    return prev;
+    return nullptr;
 }
 
 Paragraph*
@@ -168,8 +162,6 @@ Paragraph::get_sub_last() const
             p_sub = p;
         else
             break;
-
-        // TODO: two consecutive empty lines should also break
     }
 
     return p_sub;
@@ -185,15 +177,13 @@ Paragraph::get_sub_last_visible( bool F_force_1st_gen ) const
     {
         if( is_sub( p ) )
         {
-            if( p->is_visible() || ( F_force_1st_gen && p->get_parent() == this ) )
+            if( p->is_visible() && ( !F_force_1st_gen || p->get_parent() == this ) )
                 p_sub = p;
             else
                 continue;
         }
         else
             break;
-
-        // EXAMINE: two consecutive empty lines should also break?
     }
 
     return p_sub;
@@ -1379,7 +1369,7 @@ Paragraph::join_with_next()
     delete p_del;
 }
 Paragraph*
-Paragraph::split_at( UstringSize pos )
+Paragraph::split_at( UstringSize pos, ParserBackGround* parser )
 {
     if( pos >= m_text.length() )
         return( new Paragraph( m_host, "" ) );
@@ -1397,7 +1387,7 @@ Paragraph::split_at( UstringSize pos )
         }
     }
 
-    erase_text( pos, m_text.length() - pos, nullptr );
+    erase_text( pos, m_text.length() - pos, parser );
 
     return para_new;
 }
