@@ -179,7 +179,14 @@ class Paragraph : public DiaryElemDataSrc
                 // NOTE: heading values are inverse:
                 if( sub_heading_lvl > ths_heading_lvl ) return true;
                 if( sub_heading_lvl < ths_heading_lvl ) return false;
-                if( p_sub->get_indent_level() > this->get_indent_level() )   return true;
+                // empty paras cannot be parent by virtue of indentation:
+                if( m_text.empty() ) return false;
+                if( p_sub->get_indent_level() > this->get_indent_level() ) return true;
+                // bulleted paras are assumed to be parents of plain paras of same indent level:
+                if( p_sub->get_indent_level() == this->get_indent_level() &&
+                    p_sub->get_indent_level() > 0 && // exempt non-indented bullet paras
+                    p_sub->get_list_type() == 0 &&
+                    this->get_list_type() == VT::PS_BULLET) return true;
             }
 
             return false;
@@ -259,7 +266,7 @@ class Paragraph : public DiaryElemDataSrc
         int                         predict_indent_from_text();
 
         void                        join_with_next();
-        Paragraph*                  split_at( UstringSize );
+        Paragraph*                  split_at( UstringSize, ParserBackGround* = nullptr );
 
         // STYLE
         void                        inherit_style_from( const Paragraph*, bool = false );
@@ -389,6 +396,19 @@ class Paragraph : public DiaryElemDataSrc
         // URI (used by image paragraphs)
         String                      get_uri() const
         { return m_uri; }
+        String                      get_uri_broad() const
+        {
+            Ustring uri { m_uri };
+            for( auto f : m_formats )
+            {
+                if( f->type == VT::HFT_LINK_URI )
+                {
+                    if( !uri.empty() ) uri += "; ";
+                    uri += f->uri;
+                }
+            }
+            return uri;
+        }
         // String                      get_uri_unrel() const
         // { return m_p2diary->convert_rel_uri( m_uri ); }
         void                        set_uri( String uri )
