@@ -36,6 +36,23 @@ TableColumn::TableColumn( TableData* p2data, int id, Type t )
 : NamedElement( STR0/SI::NEW_COLUMN ), m_id( id ), m_p2data( p2data ), m_type( t )
 { }
 
+bool
+TableColumn::set_type( Type type )
+{
+    if( type == TCT_GANTT )
+    {
+        if( m_p2data->m_p2col_gantt )
+            return false;
+        else
+            m_p2data->m_p2col_gantt = this;
+    }
+
+    m_type = type;
+    m_summary_func = ( is_numeric() ? VT::SUMF::SUM::C : VT::SUMF::NONE::C );
+
+    return true;
+}
+
 bool
 TableColumn::is_source_elem_para() const
 {
@@ -664,7 +681,7 @@ TableColumn::calculate_value_txt( const Paragraph* para ) const
     {
         case TCT_TEXT:
             if( ( m_opt_int & VT::SEQ_FILTER ) == VT::TCT_SRC_URI )
-                return para->get_uri();
+                return para->get_uri_broad();
             else
                 return para->get_text_stripped( m_opt_int );
         case TCT_NUMBER:
@@ -757,7 +774,9 @@ TableColumn::calculate_value_date( const Paragraph* para ) const
 void
 TableColumn::calculate_value_gantt( const Paragraph* para, TableLine* line ) const
 {
-    line->m_periods.push_back( { 0.0, 0.0, para->get_date(), para->get_date_finish() } );
+    line->m_periods.push_back( { 0.0, 0.0,
+                                 para->get_date_broad(),
+                                 para->get_date_finish_broad() } );
     line->set_col_v_num( m_index, Date::get_secs_since_min( line->m_periods.front().dbgn ) );
 }
 
@@ -1336,6 +1355,7 @@ TableData::clear()
     m_F_para_based      = false;
 
     m_grouping_depth    = 0;
+    m_p2col_gantt       = nullptr;
 
     m_master_header.clear_sublines( true );
     m_lines.clear();
@@ -1862,6 +1882,8 @@ TableData::dismiss_column( int i_col )
     }
 
     ensure_sort_column();
+    if( col_del->m_type == TableColumn::TCT_GANTT )
+        m_p2col_gantt = nullptr;
 
     delete col_del;
 }
@@ -2000,7 +2022,6 @@ TableData::populate_lines( bool F_expanded, Entry* entry_single ) // use all ent
 
     FiltererContainer*  fc_entry    { nullptr };
     FiltererContainer*  fc_para     { nullptr };
-    int                 ic_gantt    { -1 };
     int                 n_added     { 0 };
 
     for( auto& col : m_columns )
@@ -2008,9 +2029,6 @@ TableData::populate_lines( bool F_expanded, Entry* entry_single ) // use all ent
         // initialize filterer stacks
         col->allocate_filter_stacks();
 
-        if( col->get_type() == TableColumn::TCT_GANTT )
-            ic_gantt = col->m_index;
-
         if( !entry_single )
         {
             col->m_value_min = Constants::INFINITY_PLS;
@@ -2059,8 +2077,8 @@ TableData::populate_lines( bool F_expanded, Entry* entry_single ) // use all ent
     if( m_count_lines > 0 )
         m_master_header.set_total_value_strings();
 
-    if( ic_gantt >= 0 ) // is set up in a second iteration as all lines depend to each other
-        set_gantt_column_coords( ic_gantt );
+    if( m_p2col_gantt ) // is set up in a second iteration as all lines depend to each other
+        set_gantt_column_coords();
 
     update_lines_cache();
 
@@ -2075,7 +2093,7 @@ TableData::populate_lines( bool F_expanded, Entry* entry_single ) // use all ent
 }
 
 void
-TableData::set_gantt_column_coords( int ic )
+TableData::set_gantt_column_coords()
 {
     DateV   date_bgn  { Date::NOT_SET };
     DateV   date_end  { Date::NOT_SET };
@@ -2088,11 +2106,11 @@ TableData::set_gantt_column_coords( int ic )
         {
             if( sl->m_p2elem ) // not header
             {
-                if( !Date::is_set( date_end ) || date_bgn > sl->m_p2elem->get_date() )
-                    date_bgn = sl->m_p2elem->get_date();
+                if( !Date::is_set( date_end ) || date_bgn > sl->m_periods.front().dbgn )
+                    date_bgn = sl->m_periods.front().dbgn;
 
-                if( !Date::is_set( date_end ) || date_end < sl->m_p2elem->get_date_finish_calc() )
-                    date_end = sl->m_p2elem->get_date_finish_calc();
+                if( !Date::is_set( date_end ) || date_end < sl->m_periods.back().dend )
+                    date_end = sl->m_periods.back().dend;
             }
 
             if( !sl->m_sublines.empty() )
@@ -2122,7 +2140,7 @@ TableData::set_gantt_column_coords( int ic )
 
     fill_subline_period_coords( &m_master_header );
     m_date_bgn = date_bgn;
-    m_master_header.set_col_v_num( ic, 0.0, span );
+    m_master_header.set_col_v_num( m_p2col_gantt->m_index, 0.0, span );
 }
 
 void
@@ -2230,6 +2248,9 @@ TableData::resort_lines()
 
     m_master_header.set_total_value_strings();
 
+    if( m_p2col_gantt ) // is set up in a second iteration as all lines depend to each other
+        set_gantt_column_coords();
+
     update_lines_cache();
 }
 
