@@ -50,16 +50,14 @@ class TableColumn : public NamedElement
 
         TableColumn( TableData* p2data, int id, Type t = TCT_TEXT );
 
-        void                        set_type( Type type )
-        {
-            m_type = type;
-            m_summary_func = ( is_numeric() ? VT::SUMF::SUM::C : VT::SUMF::NONE::C );
-        }
+        bool                        set_type( Type );
         Type                        get_type() const
         { return m_type; }
 
-        void                        set_opt_int( int32_t type )
-        { m_opt_int = type; }
+        void                        set_opt_int( int32_t value )
+        { m_opt_int = value; }
+        void                        set_opt_int_field( int32_t filter, int32_t value )
+        { m_opt_int = ( ( m_opt_int & ~filter ) | value ); }
         int32_t                     get_opt_int() const
         { return m_opt_int; }
 
@@ -452,7 +450,7 @@ class TableData
 
     protected:
         int                         generate_new_id() const;
-        void                        set_gantt_column_coords( int );
+        void                        set_gantt_column_coords();
 
         template< class T >
         TableLine* create_line( T* elem, bool F_expanded )
@@ -528,6 +526,7 @@ class TableData
         MapIdsTableColumns          m_columns_map;
         int                         m_grouping_depth    { 0 };
         int                         m_count_lines       { 0 };
+        TableColumn*                m_p2col_gantt       { nullptr };
         DateV                       m_date_bgn          { 0 }; // begin date of gantt chart
         TableLine                   m_master_header     { this, true };
         VectorTableLines            m_lines;      // basic cache of lines in sorted order
