@@ -35,11 +35,11 @@
 using namespace LIFEO;
 
 // STATIC MEMBERS
-const char                      Lifeograph::PROGRAM_VERSION_STRING[] = "3.0.0"
+const char                      Lifeograph::PROGRAM_VERSION_STRING[] = "3.0.1"
 #if LIFEOGRAPH_DEBUG_BUILD || defined( LIFEOGRAPH_BETA_STAGE )
         "\n" BUILD_TIMESTAMP
 #endif
-        "\n\"Babies are being killed before the eyes of the world\"";
+        "\n\"Be silent when children sleep not when they are massacred\"";
 
 
 Lifeograph*                     Lifeograph::p;
