@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-    Copyright (C) 2010 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2024 Ahmet Öztürk (aoz_2@yahoo.com)
 
     This file is part of Lifeograph.
 
@@ -69,21 +69,26 @@ Settings::read()
         {
             switch( line[ 0 ] )
             {
-                case 'B': // backups
-                    if( line[1] == 'd' ) // daily
+                case 'B': // daily backups
+                    if( line[ 1 ] != '_' )
                     {
                         save_backups = true;
                         if( line.size() > 2 )
-                            backup_folder_path = line.substr( 2 );
+                            backup_folder_uri = line.substr( 2 );
+                        // update old format:
+                        if( line[ 1 ] == 'd' )
+                            backup_folder_uri = Glib::filename_to_uri( backup_folder_uri );
                     }
                     break;
                 case 'D':
-                    if( line[1] == 'o' )
-                        date_format_order = std::stol( line.substr( 2 ) );
-                    else if( line[1] == 'a' )
+                    if( line[ 1 ] == 'o' )
+                        date_format_order = std::stoi( line.substr( 2 ) );
+                    else if( line[ 1 ] == 'a' )
                         use_dark_theme = true;
+                    else if( line[ 1 ] == '1' )
+                        Date::s_week_start_day = std::stoi( line.substr( 4 ) );
                     else
-                        date_format_separator = std::stol( line.substr( 2 ) );
+                        date_format_separator = std::stoi( line.substr( 2 ) );
                     break;
                 case 'E':
                     // if only a dot (.) no extension will be added automatically
@@ -94,10 +99,10 @@ Settings::read()
                 // TODO: position & size settings may go to the diary
                 // TODO: check if these are within screen boundaries
                 case 'H':
-                    height = std::stol( line.substr( 2 ) );
+                    height = std::stoi( line.substr( 2 ) );
                     break;
                 case 'I':
-                    idletime = std::stol( line.substr( 2 ) );
+                    idletime = std::stoi( line.substr( 2 ) );
                     if( idletime < 0 || idletime > IDLETIME_MAX )
                         idletime = IDLETIME_DEFAULT;
                     break;
@@ -107,16 +112,19 @@ Settings::read()
                         small_lists = false;
                     break;
                 case 'P':   // uppercase
-                    position_paned_main = std::stol( line.substr( 2 ) );
+                    position_paned_main = std::stoi( line.substr( 2 ) );
                     break;
                 case 'p':   // lowercase
-                    position_paned_extra =  std::stol( line.substr( 2 ) );
+                    position_paned_extra =  std::stoi( line.substr( 2 ) );
                     // zero width is not accepted by Gtk::Paned
                     if( position_paned_extra == 0 )
                         position_paned_extra = 1;
                     break;
                 case 'R':
-                    recentfiles.insert( line.substr( 2 ) );
+                    if( line[ 1 ] == 'u' )  // recent file v3000 version (uri)
+                        recentfiles.insert( line.substr( 2 ) );
+                    else                    // recent file pre-v3000 version (path)
+                        recentfiles.insert( Glib::filename_to_uri( line.substr( 2 ) ) );
                     break;
                 case 'S':
                     state_maximized = ( line[ 2 ] == 'm' || line[ 2 ] == 'M' );
@@ -128,13 +136,13 @@ Settings::read()
                     use_imperial_units = ( line[ 2 ] == 'i' || line[ 2 ] == 'I' );
                     break;
                 case 'W':
-                    width = std::stol( line.substr( 2 ) );
+                    width = std::stoi( line.substr( 2 ) );
                     break;
                 case 'X':
-                    position_x = std::stol( line.substr( 2 ) );
+                    position_x = std::stoi( line.substr( 2 ) );
                     break;
                 case 'Y':
-                    position_y = std::stol( line.substr( 2 ) );
+                    position_y = std::stoi( line.substr( 2 ) );
                     break;
 
                 case 0:     // empty line
@@ -162,7 +170,7 @@ Settings::write()
 {
     if( access( PATH( m_path ).c_str(), F_OK ) != 0 )
     {
-        if( ! Glib::file_test( Glib::path_get_dirname( m_path ), Glib::FILE_TEST_IS_DIR ) )
+        if( ! Glib::file_test( Glib::path_get_dirname( m_path ), Glib::FileTest::IS_DIR ) )
             g_mkdir_with_parents( Glib::path_get_dirname( m_path ).c_str(), 0700 );
     }
 
@@ -174,6 +182,8 @@ Settings::write()
         return false;
     }
 
+    file.imbue( std::locale( "C" ) ); // to eliminate thousands separators
+
     file << "W " << width;
     file << "\nH " << height;
     file << "\nX " << position_x;
@@ -183,17 +193,19 @@ Settings::write()
     file << "\np " << position_paned_extra;
 
     // RECENT FILES
-    for( const std::string& path : recentfiles )
-        file << "\nR " << path;
+    for( const String& path : recentfiles )
+        file << "\nRu" << path;
 
     file << "\nI " << idletime;
 
     file << "\nDo" << date_format_order;
     file << "\nDs" << date_format_separator;
 
+    file << "\nD1st" << Date::s_week_start_day;
+
     file << "\nU " << ( use_imperial_units ? 'i' : 'm' );
 
-    file << "\nB"  << ( save_backups ? 'd' : '_' ) << backup_folder_path;
+    file << "\nB"  << ( save_backups ? 'y' : '_' ) << backup_folder_uri;
 
     if( diary_extension != EXTENSION_DEFAULT )
         file << "\nE " << diary_extension;
@@ -220,7 +232,7 @@ Settings::reset()
     date_format_separator = 0;
     use_imperial_units = false;
     save_backups = false;
-    backup_folder_path.clear();
+    backup_folder_uri.clear();
     icon_theme.clear();
     diary_extension = EXTENSION_DEFAULT;
 }
