@@ -941,7 +941,7 @@ WidgetTable::set_up_col_opts_subtag()
 void
 WidgetTable::set_up_col_opts_text( bool F_update_only )
 {
-    // if( !m_Bx_col_opts_text )
+    if( !F_update_only )
     {
         auto&& builder{ Lifeograph::get_builder() }; //Gtk::Builder::create() };
         Lifeograph::load_gui( builder, Lifeograph::SHAREDIR + "/ui/col_opt_text.ui" );
@@ -1192,7 +1192,8 @@ WidgetTable::handle_col_type_changed()
 {
     if( Lifeograph::is_internal_operations_ongoing() ) return;
 
-    m_p2col_sel->set_type( TableColumn::Type( m_CB_col_type->get_active_row_number() ) );
+    if( !m_p2col_sel->set_type( TableColumn::Type( m_CB_col_type->get_active_row_number() ) ) )
+        return;
 
     m_p2col_sel->m_p2tag = nullptr;
     m_p2col_sel->m_opt_str.clear();
@@ -1247,7 +1248,10 @@ WidgetTable::handle_col_source_elem_changed()
     update_source_elem_filters();
 
     if( m_p2col_sel->get_type() == TableColumn::TCT_TEXT )
+    {
+        m_p2col_sel->set_opt_int_field( VT::SEQ_FILTER, VT::TCT_SRC_TITLE );
         set_up_col_opts_text( true ); // update per the source being a para or entry
+    }
 
     calculate_and_plot();
 }
