@@ -188,7 +188,7 @@ TextviewDiary::set_entry( Entry* entry )
     update_text_formatting();
     set_cursor_position( entry->get_cursor_pos() );
     update_cursor_dependent_positions();
-    scroll_to_cursor();
+    scroll_to_cursor_center();
     m_edit_operation_type = EOT::USER;
 }
 
@@ -201,7 +201,7 @@ TextviewDiary::refresh_entry( bool F_scroll_to, bool F_reset_visibilities )
     if( F_scroll_to )
     {
         set_cursor_position( pos_cursor );
-        scroll_to_cursor();
+        scroll_to_cursor_center();
     }
     update_cursor_dependent_positions();
     update_text_formatting();
@@ -941,8 +941,10 @@ TextviewDiary::calculate_token_bounds( Gtk::TextIter& it_bgn, Gtk::TextIter& it_
         }
     }
 
-    // if everything fails:
+    // if no selection and no existing tag:
     it_bgn = it_end = m_r2buffer->get_insert()->get_iter();
+    const Wchar ch_end { it_end.get_char() };
+
     // find word boundaries:
     if( it_bgn.backward_find_char( type == VT::HFT_TAG ? &STR::is_char_not_name
                                                        : &STR::is_char_space )  )
@@ -950,12 +952,21 @@ TextviewDiary::calculate_token_bounds( Gtk::TextIter& it_bgn, Gtk::TextIter& it_
 
     if( type == VT::HFT_TAG )
     {
-        if( STR::is_char_name( it_end.get_char() ) )
+        if( STR::is_char_name( ch_end ) )
             it_end.forward_find_char( &STR::is_char_not_name );
     }
-    else
-    if( !STR::is_char_space( it_end.get_char() ) )
+    else if( !STR::is_char_space( ch_end ) )
         it_end.forward_find_char( &STR::is_char_space );
+
+    // if omitting punctuation did not end well:
+    if( type == VT::HFT_TAG && it_bgn == it_end )
+    {
+        if( it_bgn.backward_find_char( &STR::is_char_space ) )
+            ++it_bgn;
+
+        if( !STR::is_char_space( ch_end ) )
+            it_end.forward_find_char( &STR::is_char_space );
+    }
 }
 
 // TEXTVIEW ========================================================================================
