@@ -215,8 +215,20 @@ class TextviewDiary : public Gtk::TextView
             scroll_to( mark, 0.05, 0.5, 0.5 );
             m_r2buffer->delete_mark( mark );
         }
-        void                        scroll_to_cursor()
+        void                        scroll_to_cursor_center()
         { scroll_to( m_r2buffer->get_insert(), 0.05, 0.5, 0.5 ); }
+        void                        scroll_to_cursor_min()
+        { scroll_to( m_r2buffer->get_insert(), 0.08 ); }
+        void                        scroll_to_top()
+        {
+            set_cursor_position( 0 );
+            scroll_to( m_r2buffer->get_insert(), 0.05 );
+        }
+        void                        scroll_to_bottom()
+        {
+            set_cursor_position( m_p2entry->get_size() );
+            scroll_to( m_r2buffer->get_insert(), 0.05 );
+        }
 
         void                        update_cursor_dependent_positions();
         void                        update_para_region_basic( int, int, Paragraph*, Paragraph*,
